pub struct ChannelKey { /* private fields */ }Expand description
Canonical key describing a channel’s schema and attachments.
Implementations
Sourceimpl ChannelKey
impl ChannelKey
Sourcepub fn new(
schema: SchemaId,
backpressure: Backpressure,
producers: impl Iterator<Item = EndpointId>,
consumers: impl Iterator<Item = EndpointId>,
) -> Self
pub fn new( schema: SchemaId, backpressure: Backpressure, producers: impl Iterator<Item = EndpointId>, consumers: impl Iterator<Item = EndpointId>, ) -> Self
Create a new channel key from producers and consumers.
Sourcepub fn contains(
&self,
schema: SchemaId,
backpressure: Backpressure,
producer: EndpointId,
consumer: EndpointId,
) -> bool
pub fn contains( &self, schema: SchemaId, backpressure: Backpressure, producer: EndpointId, consumer: EndpointId, ) -> bool
Check whether this key matches the supplied endpoints and schema.
Sourcepub fn is_compatible(&self, desired: &ChannelKey) -> bool
pub fn is_compatible(&self, desired: &ChannelKey) -> bool
Check whether the key is compatible with another key.
Sourcepub fn backpressure(&self) -> Backpressure
pub fn backpressure(&self) -> Backpressure
Return the backpressure behaviour for this channel.
Sourcepub fn producers(&self) -> &[EndpointId] ⓘ
pub fn producers(&self) -> &[EndpointId] ⓘ
Return producers on this channel.
Sourcepub fn consumers(&self) -> &[EndpointId] ⓘ
pub fn consumers(&self) -> &[EndpointId] ⓘ
Return consumers on this channel.